import 'dart:math';

import 'package:example/ble/mobx/ble_state.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/'
    'healthrian_ble_support_for_wearecg12.dart';

final bleState = BLEState();

class BlePage extends StatelessWidget {
  const BlePage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                if (!bleState.isShowingGraph) return const SizedBox();
                return StreamBuilder(
                  stream: BLEManager().streams.batteryLevelStream,
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) {
                      return const Center(child: Text('No Stream'));
                    }
                    final v = snapshot.data!;

                    const levels = [
                      Icon(
                        Icons.battery_full,
                        color: Colors.green,
                      ),
                      Icon(
                        Icons.battery_6_bar,
                        color: Colors.green,
                      ),
                      Icon(
                        Icons.battery_5_bar,
                        color: Colors.green,
                      ),
                      Icon(
                        Icons.battery_4_bar,
                        color: Colors.amber,
                      ),
                      Icon(
                        Icons.battery_3_bar,
                        color: Colors.amber,
                      ),
                      Icon(
                        Icons.battery_2_bar,
                        color: Colors.amber,
                      ),
                      Icon(
                        Icons.battery_1_bar,
                        color: Colors.redAccent,
                      ),
                      Icon(
                        Icons.battery_0_bar,
                        color: Colors.redAccent,
                      ),
                    ];

                    final index = 7 - ((v - 1) ~/ 12.5);
                    return Row(
                      children: [
                        Transform.rotate(
                          angle: pi / 2,
                          child: levels[index],
                        ),
                        Text('$v%'),
                      ],
                    );
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              onPressed: () async {
                bleState.isShowingGraph = !bleState.isShowingGraph;
              },
              child: const Icon(Icons.exit_to_app),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().connectDevice();
                await BLEManager().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().disconnectDevice();
              },
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().startMeasurementEcg();
              },
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().pauseMeasurementEcg();
              },
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().stopMeasurementEcg();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}
